@@ -6,7 +6,12 @@ import os
 
 import pandas as pd
 import synapseclient
-from synapseclient.retry import _with_retry
+
+try:
+    from synapseclient.core.retry import with_retry
+except ModuleNotFoundError:
+    # For synapseclient < v2.0
+    from synapseclient.retry import _with_retry as with_retry
 
 from . import createchallenge
 from . import download_current_lead_submission as dl_cur
@@ -44,8 +49,25 @@ def command_createchallenge(syn, args):
 
     >>> challengeutils createchallenge "Challenge Name Here"
     """
-    createchallenge.main(syn, args.challengename, args.livesiteid)
-
+    challenge_components = createchallenge.main(syn, args.challengename,
+                                                args.livesiteid)
+    # component: project or team
+    # componentid: project id or teamid
+    urls = {}
+    for component, componentid in challenge_components.items():
+        if component.endswith("projectid"):
+            urls[component] = f"https://www.synapse.org/#!Synapse:{componentid}"
+        elif component.endswith("teamid"):
+            urls[component] = f"https://www.synapse.org/#!Team:{componentid}"
+    urls['name'] = args.challengename
+    text = ("{name} (Production site): {live_projectid}",
+            "{name} (Staging site): {staging_projectid}",
+            "{name} (Admin team): {admin_teamid}",
+            "{name} (Participant team): {organizer_teamid}",
+            "{name} (Organizer team): {participant_teamid}",
+            "{name} (Pre-registrant team): {preregistrantrant_teamid}")
+    print("\n" + "\n".join(text).format(**urls))
+    return challenge_components
 
 def command_query(syn, args):
     """Command line convenience function to call evaluation queue query
@@ -186,14 +208,14 @@ def command_annotate_submission_with_json(syn, args):
     # By default is_private is True, so the cli is to_public as False
     # Which would be that is_private is True.
     is_private = not args.to_public
-    _with_retry(lambda: utils.annotate_submission_with_json(syn, args.submissionid,  # noqa pylint: disable=line-too-long
-                                                            args.annotation_values,  # noqa pylint: disable=line-too-long
-                                                            is_private=is_private,  # noqa pylint: disable=line-too-long
-                                                            force=args.force),  # noqa pylint: disable=line-too-long
-                wait=3,
-                retries=10,
-                retry_status_codes=[412, 429, 500, 502, 503, 504],
-                verbose=True)
+    with_retry(lambda: utils.annotate_submission_with_json(syn, args.submissionid,  # noqa pylint: disable=line-too-long
+                                                           args.annotation_values,  # noqa pylint: disable=line-too-long
+                                                           is_private=is_private,  # noqa pylint: disable=line-too-long
+                                                           force=args.force),  # noqa pylint: disable=line-too-long
+               wait=3,
+               retries=10,
+               retry_status_codes=[412, 429, 500, 502, 503, 504],
+               verbose=True)
 
 
 def command_send_email(syn, args):
