@@ -5,7 +5,11 @@ import json
 import requests
 
 import synapseclient
-from synapseclient.utils import id_of
+try:
+    from synapseclient.core.utils import id_of
+except ModuleNotFoundError:
+    # For synapseclient < v2.0
+    from synapseclient.utils import id_of
 
 from synapseservices.discussion import Forum
 
